{% load i18n %}
<div class="plugin_twitter">
	{% if object.title %}<h2>{{ object.title }}</h2>{% endif %}
    <a class="twitter-timeline"  href="https://twitter.com/search?q={{ object.query|iriencode }}"  data-widget-id="{{ object.twitter_id }}"
       data-tweet-limit="{{ object.count }}" data-show-replies="false">Tweet</a>
    <script>!function(d,s,id){var js,fjs=d.getElementsByTagName(s)[0];if(!d.getElementById(id)){js=d.createElement(s);js.id=id;js.src="//platform.twitter.com/widgets.js";fjs.parentNode.insertBefore(js,fjs);}}(document,"script","twitter-wjs");</script>
</div>
